package org.opensourcephysics.display;

/**
 * The Data interface specifies the type of OSP data that an object provides to other objects.
 *
 * @author Wolfgang Christian
 * @version 1.0
 */
public interface Data{

   /**
    * Gets a 2D array of data.
    * The first column, double[0][] often contains x-values;
    * remaining columns often contain y values.
    *
    * May return null if data has not yet been generated or if the object does not support array data.
    *
    * @return double[][]
    */
   public double[][] getData();

   /**
    * Gets a 3D array of data.
    *
    * May return null if data has not yet been generated or if the object does not support xyz array data.
    *
    * @return double[][]
    */
   public double[][][] getDataXYZ();



   /**
    * Gets an array of datasets.
    * May return null if data has not yet been generated or if the object does not support datasets.
    *
    * @return Dataset[]
    */
   public Dataset[] getDatasets();

   /**
    * Gets an array of complex datasets.
    * May return null if data has not yet been generated or if the object does not support complex datasets.
    *
    * @return ComplexDataset[]
    */
   public ComplexDataset[] getComplexDatasets();

}
