/*
 * The org.opensourcephysics.media.core package defines the Open Source Physics
 * media framework for working with video and other media.
 *
 * Copyright (c) 2004  Douglas Brown and Wolfgang Christian.
 *
 * This is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston MA 02111-1307 USA
 * or view the license online at http://www.gnu.org/copyleft/gpl.html
 *
 * For additional information and documentation on Open Source Physics,
 * please see <http://www.opensourcephysics.org/>.
 */
package org.opensourcephysics.media.core;
import java.util.*;

/**
 * String resources for media classes.
 *
 * @author Douglas Brown
 * @version 1.0
 */
public class MediaRes {
   // static fields
   private static String BUNDLE_NAME = "org.opensourcephysics.resources.media.video"; //$NON-NLS-1$
   static ResourceBundle res = ResourceBundle.getBundle(BUNDLE_NAME,Locale.getDefault());

   /**
    * Private constructor to prevent instantiation.
    */
   private MediaRes() {/** empty block */}

   /**
    * Gets the localized value of a string. If no localized value is found, the
    * key is returned surrounded by exclamation points.
    *
    * @param key the string to localize
    * @return the localized string
    */
   public static String getString(String key) {
      try {
         return res.getString(key);
      } catch(MissingResourceException ex) {
         return "!"+key+"!"; //$NON-NLS-1$ //$NON-NLS-2$
      }
   }

   /**
    * Sets the locale.
    *
    * @param locale the locale
    */
   public static void setLocale(Locale locale){
      res = ResourceBundle.getBundle(BUNDLE_NAME, locale);
   }

}
